*==============================================================================
* Program:			GetTimeZoneInfo
* Purpose:			Gets time zone information
* Author:			Doug Hennig
* Copyright:		(c) 2015 Stonefield Software Inc.
* Last Revision:	09/10/2015
* Parameters:		none
* Returns:			an object with TimeZoneDesc and TimeZoneOffset properties
* Environment in:	none
* Environment out:	none
*==============================================================================

local loObject, ;
	lcTimeZone, ;
	lnID, ;
	lnStandardOffset, ;
	lnDaylightOffset

* Create an object to hold the time zone information.

loObject = createobject('Empty')
addproperty(loObject, 'TimeZoneDesc')
addproperty(loObject, 'TimeZoneOffset')

* Declare the time zone information API function and get the time zone
* information.
 
#define TIME_ZONE_SIZE  172
declare integer GetTimeZoneInformation in kernel32 ;
	string @lpTimeZoneInformation
lcTimeZone = replicate(chr(0), TIME_ZONE_SIZE)
lnID       = GetTimeZoneInformation(@lcTimeZone)

* Determine the standard and daylight time offset.
 
lnStandardOffset = ctobin(substr(lcTimeZone,   1, 4), '4RS')
lnDaylightOffset = ctobin(substr(lcTimeZone, 169, 4), '4RS')

* Determine the total offset based on whether the computer is on daylight time
* or not. Get the description for the time zone.
 
if lnID = 2  && daylight time
	loObject.TimeZoneDesc   = strtran(strconv(substr(lcTimeZone, 89, 64), ;
		6), chr(0), '')
	loObject.TimeZoneOffset = (lnStandardOffset + lnDaylightOffset) * 60
else   && standard time
	loObject.TimeZoneDesc   = strtran(strconv(substr(lcTimeZone,  5, 64), ;
		6), chr(0), '')
	loObject.TimeZoneOffset = lnStandardOffset * 60
endif lnID = 2
return loObject
